@@ -138,7 +138,7 @@ to_fac_helper <- function(x, add.non.labelled, ref.lvl) {
   # set back value labels
   x <- suppressMessages(set_labels(x, labels = lab.switch, force.labels = TRUE, force.values = FALSE))
   # set back variable labels
-  x <- set_label(x, varlab)
+  x <- set_label(x, label = varlab)
   # change reference level?
   if (!is.null(ref.lvl)) x <- ref_lvl(x, value = ref.lvl)
   return(x)
